build.descendants returns a named list of vectors.
Each component corresponds to a node \(x\) of the graph, and its vector is the set of its descendants including also \(x\).
build.descendants.per.level returns a named list of vectors.
Each component corresponds to a node \(x\) of the graph and its vector is the set of its descendants including also \(x\).
The nodes are ordered from root (included) to leaves.
build.descendants.bottom.up returns a named list of vectors.
Each component corresponds to a node \(x\) of the graph and its vector is the set of its descendants including also \(x\).
The nodes are ordered from leaves to root (included).